==> uknc-everywhere-1.0.tar.bz2: uknc-everywhere-1.0/Settings.cpp <==
#include <limits.h>
#include <QSettings>
#include "compat.h"

void Settings_GetFloppyFilePath(int slot, LPTSTR buffer) {
  QSettings settings;
  QByteArray arr = settings.value( QString("Floppy%1").arg(slot) ).toString().toLocal8Bit();
  strncpy( buffer, arr.data(), PATH_MAX );
}

void Settings_SetFloppyFilePath(int slot, LPCTSTR sFilePath) {
  QSettings settings;
  settings.setValue( QString("Floppy%1").arg(slot), QString::fromLocal8Bit( sFilePath ) );
}

void Settings_GetCartridgeFilePath(int slot, LPTSTR buffer) {
  QSettings settings;
  QByteArray arr = settings.value( QString("Cartridge%1").arg(slot) ).toString().toLocal8Bit();
  strncpy( buffer, arr.data(), PATH_MAX );
}

void Settings_SetCartridgeFilePath(int slot, LPCTSTR sFilePath) {
  QSettings settings;
  settings.setValue( QString("Cartridge%1").arg(slot), QString::fromLocal8Bit( sFilePath ) );
}

void Settings_SetScreenViewMode(int mode) {
  QSettings settings;
  settings.setValue( "ScreenViewMode", mode );
}

int Settings_GetScreenViewMode() {
  QSettings settings;
  return settings.value( "ScreenViewMode" ).toInt();
}

void Settings_SetScreenHeightMode(int mode) {
  QSettings settings;
  settings.setValue( "ScreenHeightMode", mode );
}

int Settings_GetScreenHeightMode() {
  QSettings settings;
  return settings.value( "ScreenHeightMode" ).toInt();
}

#define DEF_BOOL_SETTING(name, defval)               \
  void Settings_Set##name(BOOL flag) {               \
    QSettings settings;                              \
    settings.setValue( #name, flag );                \
  }                                                  \
  BOOL Settings_Get##name() {                        \
    QSettings settings;                              \
    return settings.value( #name, defval ).toBool(); \
  }

DEF_BOOL_SETTING( Debug,     false )
DEF_BOOL_SETTING( Autostart, true  )
DEF_BOOL_SETTING( RealSpeed, false )
DEF_BOOL_SETTING( Keyboard,  true  )
DEF_BOOL_SETTING( Tape,      false )

==> uknc-everywhere-1.1.tar.bz2: uknc-everywhere-1.1/Settings.cpp <==
#include <limits.h>
#include <QSettings>
#include "compat.h"

QString Settings_GetFloppyFilePath(int slot) {
  QSettings settings;
  return settings.value( QString("Floppy%1").arg(slot) ).toString();
}

void Settings_SetFloppyFilePath(int slot, const QString& sFilePath) {
  QSettings settings;
  settings.setValue( QString("Floppy%1").arg(slot), sFilePath );
}

QString Settings_GetCartridgeFilePath(int slot) {
  QSettings settings;
  return settings.value( QString("Cartridge%1").arg(slot) ).toString();
}

void Settings_SetCartridgeFilePath(int slot, const QString& sFilePath) {
  QSettings settings;
  settings.setValue( QString("Cartridge%1").arg(slot), sFilePath );
}

void Settings_SetScreenViewMode(int mode) {
  QSettings settings;
  settings.setValue( "ScreenViewMode", mode );
}

int Settings_GetScreenViewMode() {
  QSettings settings;
  return settings.value( "ScreenViewMode" ).toInt();
}

void Settings_SetScreenHeightMode(int mode) {
  QSettings settings;
  settings.setValue( "ScreenHeightMode", mode );
}

int Settings_GetScreenHeightMode() {
  QSettings settings;
  return settings.value( "ScreenHeightMode" ).toInt();
}

#define DEF_BOOL_SETTING(name, defval)               \
  void Settings_Set##name(BOOL flag) {               \
    QSettings settings;                              \
    settings.setValue( #name, flag );                \
  }                                                  \
  BOOL Settings_Get##name() {                        \
    QSettings settings;                              \
    return settings.value( #name, defval ).toBool(); \
  }

DEF_BOOL_SETTING( Debug,     false )
DEF_BOOL_SETTING( Autostart, true  )
DEF_BOOL_SETTING( RealSpeed, false )
DEF_BOOL_SETTING( Keyboard,  true  )
DEF_BOOL_SETTING( Tape,      false )
